CONTENT = """Welcome to WhiteFly!
===================

Create Change
-------------

Create the change by editing the files **update.sql** and **rollback.sql**.


Setting Environments
-------------
Run below command to add a new environment:
```
whitefly env add <env-name> <connection-str>
```


Commit Change
-------------
Run below command to commit your change:
```
whitefly commit -m "Your commit message"
```
"""



import os
import json
import color
import readme

class Init():
   def __init__(self):
      self.WORKSPACE_DIR=".whitefly"
      self.validTypes = ["oracle","mongo","cassandra"]

   def generateReadMe(self, type):
      return readme.CONTENT

   def generateConfig(self, type):
      return json.dumps({"type": type})

   def validateType(self, type):
      if not type in self.validTypes:
         msg = color.RED + color.BOLD + type + color.END + " is not a valid type.\n"
         msg = msg + "\nValid types are:"
         for validType in validTypes:
            msg = msg + "\n\t* " + color.BOLD + validType + color.END
         raise Exception(msg)

   def createWhiteflyDir(self, whiteflyDir):
      os.mkdir(whiteflyDir)
      os.mkdir(os.path.join(whiteflyDir, self.WORKSPACE_DIR))

   def createGitignoreFile(self, whiteflyDir):
      fo = open(os.path.join(whiteflyDir, ".gitignore"), "w")
      fo.write(self.WORKSPACE_DIR)
      fo.close()

   def createConfigFile(self, whiteflyDir, type):
      fo = open(os.path.join(whiteflyDir, ".whiteflyconfig"), "w")
      fo.write(self.generateConfig(type))
      fo.close()

   def createReadMeFile(self, whiteflyDir, type):
      fo = open(os.path.join(whiteflyDir, "README.md"), "w")
      fo.write(self.generateReadMe(type))
      fo.close()

   def createUpdateFile(self, whiteflyDir, type):
      fo = open(os.path.join(whiteflyDir, "update.sql"), "w")
      fo.close()

   def createRollbackFile(self, whiteflyDir, type):
      fo = open(os.path.join(whiteflyDir, "rollback.sql"), "w")
      fo.close()

   def help(self):
      print("usage: whitefly init [db-type] [db-name]")

   def init(self, args):
      try:
         type = args[0].lower()
         name = args[1].lower()
         self.validateType(type)
         whiteflyDir = os.path.join(os.getcwd(), name)
         self.createWhiteflyDir(whiteflyDir)
         self.createGitignoreFile(whiteflyDir)
         self.createConfigFile(whiteflyDir, type)
         self.createReadMeFile(whiteflyDir, type)
         self.createUpdateFile(whiteflyDir, type)
         self.createRollbackFile(whiteflyDir, type)
         print("Initialized empty whitefly workspace in " + whiteflyDir)
      except OSError, e:
         if e.errno == os.errno.EEXIST:
            print 'ERROR - Workspace is already created.'
         else:
            print e
         raise e
         



import sys
import release
import init

class CLI():
   def __init__(self):
      self.action = None
      self.args = []
      self.error = False

   def parse(self, args):
      if len(sys.argv) == 1:
         self.error = True
         self.errorDisplay = "help"
      elif sys.argv[1] == "--help" or sys.argv[1] == "-h":
         self.action = "help"
      elif sys.argv[1] == "--version" or sys.argv[1] == "-v":
         self.action = "version"
      elif sys.argv[1] == "init":
         if len(sys.argv) == 4:
            self.action = "init"
            self.args.append(sys.argv[2])
            self.args.append(sys.argv[3])
         else:
            self.error = True
            self.action = "init_help"
      else:
         self.error = True
         self.action = "help"

   def execute(self, args):
      self.parse(args)
      fn = getattr(self, "execute_%s" % self.action)
      fn()
      if self.error:
         sys.exit(1)

   def execute_init(self):
      try:
         Init = init.Init()
         Init.init(self.args)
      except:
         sys.exit(1)

   def execute_version(self):
      print("whitefly version " + release.VERSION + " (" + release.CODENAME + ")")


   def execute_help(self):
      self.help()

   def execute_init_help(self):
      Init = init.Init()
      Init.help()

   def help(self):
      print("usage: whitefly [--version] [--help] <command> [<args?]")
      print("")
      print("These are common Whitefly commands used in various situations:")
      print("")
      print("Start a working area:")
      print("init       Create an empty Whitefly workspace")



from distutils.core import setup
setup(
  name = 'whitefly',
  packages = ['whitefly'],
  version = '0.0.2.1',
  description = 'Making the database migrations the easiest step on continuous delivery',
  author = 'Mehmet Ali Aydin',
  author_email = 'maaydin@gmail.com',
  url = 'https://github.com/kloiasoft/whitefly',
  download_url = 'https://github.com/kloiasoft/whitefly/archive/0.0.2.tar.gz',
  keywords = ['db', 'database', 'migration'],
  classifiers = [],
  scripts=['bin/whitefly'],
)
